@@ -1,7 +1,7 @@
 package Bencher::Scenario::CompleteUtil::complete_array_elem;
 
-our $DATE = '2016-01-05'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-06-26'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,8 +10,8 @@ use warnings;
 our $scenario = {
     summary => 'Benchmark complete_array_elem()',
     modules => {
-        'Complete::Util' => 0.45,
-        'Text::Levenshtein::XS' => 0,
+        'Complete::Util' => {version=>0.45},
+        'Text::Levenshtein::XS' => {version=>0},
     },
     participants => [
         {
@@ -204,11 +204,11 @@ __END__
 
 =head1 NAME
 
-Bencher::Scenario::CompleteUtil::complete_array_elem
+Bencher::Scenario::CompleteUtil::complete_array_elem - Benchmark complete_array_elem()
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::CompleteUtil::complete_array_elem (from Perl distribution Bencher-Scenarios-CompleteUtil), released on 2016-01-05.
+This document describes version 0.03 of Bencher::Scenario::CompleteUtil::complete_array_elem (from Perl distribution Bencher-Scenarios-CompleteUtil), released on 2016-06-26.
 
 =head1 SYNOPSIS
 
@@ -218,6 +218,14 @@ To run benchmark with default option:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 BENCHMARKED MODULES
+
+Version numbers shown below are the versions used when running the sample benchmark.
+
+L<Complete::Util> 0.46
+
+L<Text::Levenshtein::XS> 0.503
+
 =head1 BENCHMARK PARTICIPANTS
 
 =over
@@ -254,21 +262,21 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
-Benchmark with default option:
+Benchmark with default options (C<< bencher -m CompleteUtil::complete_array_elem >>):
 
- +-----+------------------+----------+-------------+---------+---------+
- | seq | name             | rate     | time        | errors  | samples |
- +-----+------------------+----------+-------------+---------+---------+
- | 5   | fuzzy-pp-1000    | 3.14     | 318ms       | 0.00012 | 20      |
- | 6   | fuzzy-pp-100     | 23.8     | 42ms        | 3.9e-05 | 20      |
- | 4   | fuzzy-xs-1000    | 65.4     | 15.3ms      | 1.3e-05 | 20      |
- | 2   | wordmode-1000    | 526      | 1.9ms       | 1.3e-06 | 20      |
- | 3   | charmode-1000    | 973      | 1.03ms      | 4.3e-07 | 20      |
- | 1   | prefix-1000      | 2118     | 0.472ms     | 5.3e-08 | 20      |
- | 0   | prefix-noci-1000 | 3229.377 | 0.3096573ms | 3.9e-11 | 20      |
- +-----+------------------+----------+-------------+---------+---------+
+ +------------------+-----------+-----------+------------+----------+---------+
+ | participant      | rate (/s) | time (ms) | vs_slowest |  errors  | samples |
+ +------------------+-----------+-----------+------------+----------+---------+
+ | fuzzy-pp-1000    |       4.9 |   200     |        1   |   0.0003 |      20 |
+ | fuzzy-pp-100     |      37   |    27     |        7.6 | 2.9e-05  |      20 |
+ | fuzzy-xs-1000    |     110   |     9.1   |       22   | 2.3e-05  |      20 |
+ | wordmode-1000    |     800   |     1.2   |      160   | 6.2e-06  |      20 |
+ | charmode-1000    |    1330   |     0.75  |      270   | 2.1e-07  |      20 |
+ | prefix-1000      |    2830   |     0.354 |      573   | 1.6e-07  |      20 |
+ | prefix-noci-1000 |    3600   |     0.277 |      730   | 4.6e-08  |      27 |
+ +------------------+-----------+-----------+------------+----------+---------+
 
 =head1 DESCRIPTION
 
